@@ -7,6 +7,7 @@ A tool to help keep .mailmap and AUTHORS up-to-date.
 # - Check doc/src/aboutus.rst
 # - Make it easier to update .mailmap or AUTHORS with the correct entries.
 
+from __future__ import unicode_literals
 from __future__ import print_function
 
 import os
@@ -46,12 +47,12 @@ with open(os.path.realpath(os.path.join(__file__, os.path.pardir,
     os.path.pardir, "AUTHORS"))) as fd:
     AUTHORS = unicode(fd.read(), 'utf-8')
 
-firstauthor = u"Ondřej Čertík"
+firstauthor = "Ondřej Čertík"
 
 authors = AUTHORS[AUTHORS.find(firstauthor):].strip().split('\n')
 
 # People who don't want to be listed in AUTHORS
-authors_skip = ["Kirill Smelkov <kirr@landau.phys.spbu.ru>"]
+authors_skip = ["Kirill Smelkov <kirr@landau.phys.spbu.ru>", "Sergey B Kirpichev <skirpichev@gmail.com>"]
 
 predate_git = 0
 
@@ -59,10 +60,8 @@ exit1 = False
 
 print(blue(filldedent("""Read the text at the top of AUTHORS and the text at
 the top of .mailmap for information on how to fix the below errors.  If
-someone is missing from AUTHORS, add them where they would have been if they
-were added after their first pull request was merged (checkout the merge
-commit from the first pull request and see who is at the end of the AUTHORS
-file at that commit.)""")))
+someone is missing from AUTHORS, use the ./bin/update_authors.py script to add
+them.""")))
 
 print()
 print(yellow("People who are in AUTHORS but not in git:"))
@@ -103,8 +102,7 @@ if git_count != adjusted_authors_count:
 else:
     print()
     print(green(filldedent("""Congratulations. The AUTHORS and .mailmap files
-appear to be up to date. You should now verify that doc/src/aboutus has %s
-people.""" % authors_count)))
+appear to be up to date. There are %s authors.""" % authors_count)))
 
 if exit1:
     print()
