@@ -7,7 +7,7 @@ Demonstrates matrix computations using the Vandermonde matrix.
 """
 
 from sympy import Matrix, pprint, Rational, sqrt, symbols, Symbol, zeros
-from sympy.core.compatibility import xrange
+from sympy.core.compatibility import range
 
 
 def symbol_gen(sym_str):
@@ -40,7 +40,7 @@ def comb_w_rep(n, k):
 
 
 def vandermonde(order, dim=1, syms='a b c d'):
-    """Comptutes a Vandermonde matrix of given order and dimension.
+    """Computes a Vandermonde matrix of given order and dimension.
 
     Define syms to give beginning strings for temporary variables.
 
@@ -100,7 +100,7 @@ def gen_poly(points, order, syms):
     V_pts = V.subs(subs_dict)
     V_inv = V_pts.inv()
 
-    coeffs = V_inv.multiply(Matrix([points[i][-1] for i in xrange(num_pts)]))
+    coeffs = V_inv.multiply(Matrix([points[i][-1] for i in range(num_pts)]))
 
     f = 0
     for j, term in enumerate(terms):
@@ -118,7 +118,7 @@ def main():
     pprint(V)
 
     print('-'*79)
-    print("Computing the determinate and comparing to \sum_{0<i<j<=3}(a_j - a_i)")
+    print("Computing the determinant and comparing to \sum_{0<i<j<=3}(a_j - a_i)")
 
     det_sum = 1
     for j in range(order + 1):
