@@ -136,7 +136,7 @@ def prepare_apt():
     dependencies.
     """
     sudo("apt-get -qq update")
-    sudo("apt-get -y install git python3 make python-virtualenv zip python-dev")
+    sudo("apt-get -y install git python3 make python-virtualenv zip python-dev python-mpmath")
     # Needed to build the docs
     sudo("apt-get -y install graphviz inkscape texlive texlive-xetex texlive-fonts-recommended texlive-latex-extra librsvg2-bin docbook2x")
     # Our Ubuntu is too old to include Python 3.3
@@ -299,7 +299,7 @@ def build_docs():
     with cd("/home/vagrant/repos/sympy"):
         run("mkdir -p dist")
         venv = "/home/vagrant/docs-virtualenv"
-        make_virtualenv(venv, dependencies=['sphinx==1.1.3', 'numpy'])
+        make_virtualenv(venv, dependencies=['sphinx==1.1.3', 'numpy', 'mpmath'])
         with virtualenv(venv):
             with cd("/home/vagrant/repos/sympy/doc"):
                 run("make clean")
@@ -369,19 +369,19 @@ git_whitelist = {
     '.mailmap',
     # Travis
     '.travis.yml',
-    # This is the file you should edit if not enough ends up in the tarball
-    'MANIFEST.in',
-    # Experimental Cythonization support. Not for production
-    'Makefile',
+    # Code of conduct
+    'CODE_OF_CONDUCT.md',
     # Nothing from bin/ should be shipped unless we intend to install it. Most
     # of this stuff is for development anyway. To run the tests from the
     # tarball, use setup.py test, or import sympy and run sympy.test() or
     # sympy.doctest().
     'bin/adapt_paths.py',
     'bin/ask_update.py',
+    'bin/authors_update.py',
     'bin/coverage_doctest.py',
     'bin/coverage_report.py',
     'bin/build_doc.sh',
+    'bin/deploy_doc.sh',
     'bin/diagnose_imports',
     'bin/doctest',
     'bin/generate_test_list.py',
@@ -396,8 +396,6 @@ git_whitelist = {
     'bin/test_import.py',
     'bin/test_isolated',
     'bin/test_travis.sh',
-    # This is also related to Cythonization
-    'build.py',
     # The notebooks are not ready for shipping yet. They need to be cleaned
     # up, and preferrably doctested.  See also
     # https://github.com/sympy/sympy/issues/6039.
@@ -416,6 +414,7 @@ git_whitelist = {
     'examples/notebooks/sho1d_example.ipynb',
     'examples/notebooks/spin.ipynb',
     'examples/notebooks/trace.ipynb',
+    'examples/notebooks/README.txt',
     # This stuff :)
     'release/.gitignore',
     'release/README.md',
@@ -431,7 +430,15 @@ git_whitelist = {
 # Files that should be in the tarball should not be in git
 
 tarball_whitelist = {
-    "PKG-INFO", # Generated by setup.py. Contains metadata for PyPI.
+    # Generated by setup.py. Contains metadata for PyPI.
+    "PKG-INFO",
+    # Generated by setuptools. More metadata.
+    'setup.cfg',
+    'sympy.egg-info/PKG-INFO',
+    'sympy.egg-info/SOURCES.txt',
+    'sympy.egg-info/dependency_links.txt',
+    'sympy.egg-info/requires.txt',
+    'sympy.egg-info/top_level.txt',
     }
 
 @task
@@ -551,8 +558,7 @@ def table():
             name = get_tarball_name(key)
             with tag('tr'):
                 with tag('td'):
-                    # code renders better than tt or pre
-                    with tag('code'):
+                    with tag('b'):
                         table.append(name)
                 with tag('td'):
                     table.append(descriptions[key].format(**tarball_formatter_dict))
@@ -959,7 +965,7 @@ See https://github.com/sympy/sympy/wiki/release-notes-for-{shortversion} for the
 
 {htmltable}
 
-**Note**: Do not download the `Source code (zip)` or the `Source code (tar.gz)`
+**Note**: Do not download the **Source code (zip)** or the **Source code (tar.gz)**
 files below.
 """
     out = out.format(shortversion=shortversion, htmltable=htmltable)
