@@ -1,5 +1,5 @@
-from sympy.core import Set, Dict, Tuple
 from .cartan_type import Standard_Cartan
+from sympy.core.compatibility import range
 from sympy.matrices import eye
 
 class TypeC(Standard_Cartan):
@@ -11,11 +11,11 @@ class TypeC(Standard_Cartan):
 
 
     def dimension(self):
-        """
-        Return the dimension of the vector space
-        V underlying the Lie algebra
-        Example
+        """Dimension of the vector space V underlying the Lie algebra
+
+        Examples
         ========
+
         >>> from sympy.liealgebras.cartan_type import CartanType
         >>> c = CartanType("C3")
         >>> c.dimension()
@@ -25,10 +25,7 @@ class TypeC(Standard_Cartan):
         return n
 
     def basic_root(self, i, j):
-        """
-        This is a method just to generate roots
-        with a 1 iin the ith position and a -1
-        in the jth postion.
+        """Generate roots with 1 in ith position and a -1 in jth postion
         """
         n = self.n
         root = [0]*n
@@ -37,7 +34,8 @@ class TypeC(Standard_Cartan):
         return root
 
     def simple_root(self, i):
-        """
+        """The ith simple root for the C series
+
         Every lie algebra has a unique root system.
         Given a root system Q, there is a subset of the
         roots such that an element of Q is called a
@@ -53,9 +51,9 @@ class TypeC(Standard_Cartan):
         nth simple root is the root in which there is a 2 in
         the nth position and zeroes elsewhere.
 
-        This method returns the ith simple root for the C series
-        Example
+        Examples
         ========
+
         >>> from sympy.liealgebras.cartan_type import CartanType
         >>> c = CartanType("C3")
         >>> c.simple_root(2)
@@ -73,19 +71,20 @@ class TypeC(Standard_Cartan):
 
 
     def positive_roots(self):
-        """
-        This method generates all the positive roots of
-        A_n.  This is half of all of the roots of C_n;
-        by multiplying all the positive roots by -1 we
-        get the negative roots.
+        """Generates all the positive roots of A_n
+
+        This is half of all of the roots of C_n; by multiplying all the
+        positive roots by -1 we get the negative roots.
+
+        Examples
+        ========
 
-        Example
-        ======
         >>> from sympy.liealgebras.cartan_type import CartanType
         >>> c = CartanType("A3")
         >>> c.positive_roots()
         {1: [1, -1, 0, 0], 2: [1, 0, -1, 0], 3: [1, 0, 0, -1], 4: [0, 1, -1, 0],
                 5: [0, 1, 0, -1], 6: [0, 0, 1, -1]}
+
         """
 
         n = self.n
@@ -117,15 +116,16 @@ class TypeC(Standard_Cartan):
         return 2*(n**2)
 
     def cartan_matrix(self):
-        """
-        Returns the Cartan matrix for C_n.
+        """The Cartan matrix for C_n
+
         The Cartan matrix matrix for a Lie algebra is
         generated by assigning an ordering to the simple
         roots, (alpha[1], ...., alpha[l]).  Then the ijth
         entry of the Cartan matrix is (<alpha[i],alpha[j]>).
 
-        Example
-        =======
+        Examples
+        ========
+
         >>> from sympy.liealgebras.cartan_type import CartanType
         >>> c = CartanType('C4')
         >>> c.cartan_matrix()
@@ -167,6 +167,6 @@ class TypeC(Standard_Cartan):
 
     def dynkin_diagram(self):
         n = self.n
-        diag = "---".join("0" for i in range (1, n)) + "=<=0\n"
-        diag += "   ".join(str(i) for i in range (1, n+1))
+        diag = "---".join("0" for i in range(1, n)) + "=<=0\n"
+        diag += "   ".join(str(i) for i in range(1, n+1))
         return diag
