@@ -1,10 +1,9 @@
 from __future__ import print_function, division
 
-from sympy import Basic, Q
+from sympy import Basic
 from sympy.functions import adjoint, conjugate
 
 from sympy.matrices.expressions.matexpr import MatrixExpr
-from sympy.matrices import MatrixBase
 
 class Transpose(MatrixExpr):
     """
@@ -74,3 +73,25 @@ class Transpose(MatrixExpr):
 def transpose(expr):
     """ Matrix transpose """
     return Transpose(expr).doit()
+
+
+from sympy.assumptions.ask import ask, Q
+from sympy.assumptions.refine import handlers_dict
+
+
+def refine_Transpose(expr, assumptions):
+    """
+    >>> from sympy import MatrixSymbol, Q, assuming, refine
+    >>> X = MatrixSymbol('X', 2, 2)
+    >>> X.T
+    X'
+    >>> with assuming(Q.symmetric(X)):
+    ...     print(refine(X.T))
+    X
+    """
+    if ask(Q.symmetric(expr), assumptions):
+        return expr.arg
+
+    return expr
+
+handlers_dict['Transpose'] = refine_Transpose
