@@ -8,7 +8,7 @@ from util import strided_range, billboard_matrix
 from util import get_direction_vectors
 from util import dot_product, vec_sub, vec_mag
 from sympy.core import S
-from sympy.core.compatibility import is_sequence
+from sympy.core.compatibility import is_sequence, range
 
 
 class PlotAxes(PlotObject):
