@@ -52,7 +52,7 @@ from sympy.polys.polyconfig import query
 
 from sympy.ntheory import nextprime
 
-from sympy.core.compatibility import xrange
+from sympy.core.compatibility import range
 
 
 def dup_half_gcdex(f, g, K):
@@ -317,10 +317,13 @@ def dup_inner_subresultants(f, g, K):
     """
     Subresultant PRS algorithm in `K[x]`.
 
-    Computes the subresultant polynomial remainder sequence (PRS) of `f`
-    and `g`, and the values for `\beta_i` and `\delta_i`. The last two
-    sequences of values are necessary for computing the resultant in
-    :func:`dup_prs_resultant`.
+    Computes the subresultant polynomial remainder sequence (PRS)
+    and the non-zero scalar subresultants of `f` and `g`.
+    By [1] Thm. 3, these are the constants '-c' (- to optimize
+    computation of sign).
+    The first subdeterminant is set to 1 by convention to match
+    the polynomial and the scalar subdeterminants.
+    If 'deg(f) < deg(g)', the subresultants of '(g,f)' are computed.
 
     Examples
     ========
@@ -329,7 +332,13 @@ def dup_inner_subresultants(f, g, K):
     >>> R, x = ring("x", ZZ)
 
     >>> R.dup_inner_subresultants(x**2 + 1, x**2 - 1)
-    ([x**2 + 1, x**2 - 1, -2], [-1, -1], [0, 2])
+    ([x**2 + 1, x**2 - 1, -2], [1, 1, 4])
+
+    References
+    ==========
+
+    [1] W.S. Brown, The Subresultant PRS Algorithm.
+    ACM Transaction of Mathematical Software 4 (1978) 237-249
 
     """
     n = dup_degree(f)
@@ -339,44 +348,49 @@ def dup_inner_subresultants(f, g, K):
         f, g = g, f
         n, m = m, n
 
+    if not f:
+        return [], []
+
+    if not g:
+        return [f], [K.one]
+
     R = [f, g]
     d = n - m
 
     b = (-K.one)**(d + 1)
-    c = -K.one
-
-    B, D = [b], [d]
-
-    if not f or not g:
-        return R, B, D
 
     h = dup_prem(f, g, K)
     h = dup_mul_ground(h, b, K)
 
+    lc = dup_LC(g, K)
+    c = lc**d
+
+    # Conventional first scalar subdeterminant is 1
+    S = [K.one, c]
+    c = -c
+
     while h:
         k = dup_degree(h)
         R.append(h)
 
-        lc = dup_LC(g, K)
-
-        if not d:
-            q = c
-        else:
-            q = c**(d - 1)
-
-        c = K.quo((-lc)**d, q)
-        b = -lc * c**(m - k)
-
         f, g, m, d = g, h, k, m - k
 
-        B.append(b)
-        D.append(d)
+        b = -lc * c**d
 
         h = dup_prem(f, g, K)
-
         h = dup_quo_ground(h, b, K)
 
-    return R, B, D
+        lc = dup_LC(g, K)
+
+        if d > 1:        # abnormal case
+            q = c**(d - 1)
+            c = K.quo((-lc)**d, q)
+        else:
+            c = -lc
+
+        S.append(-c)
+
+    return R, S
 
 
 def dup_subresultants(f, g, K):
@@ -413,38 +427,12 @@ def dup_prs_resultant(f, g, K):
     if not f or not g:
         return (K.zero, [])
 
-    R, B, D = dup_inner_subresultants(f, g, K)
+    R, S = dup_inner_subresultants(f, g, K)
 
     if dup_degree(R[-1]) > 0:
         return (K.zero, R)
-    if R[-2] == [K.one]:
-        return (dup_LC(R[-1], K), R)
 
-    s, i = 1, 1
-    p, q = K.one, K.one
-
-    for b, d in list(zip(B, D))[:-1]:
-        du = dup_degree(R[i - 1])
-        dv = dup_degree(R[i  ])
-        dw = dup_degree(R[i + 1])
-
-        if du % 2 and dv % 2:
-            s = -s
-
-        lc, i = dup_LC(R[i], K), i + 1
-
-        p *= b**dv * lc**(du - dw)
-        q *= lc**(dv*(1 + d))
-
-    if s < 0:
-        p = -p
-
-    i = dup_degree(R[-2])
-
-    res = dup_LC(R[-1], K)**i
-    res = K.quo(res*p, q)
-
-    return res, R
+    return S[-1], R
 
 
 def dup_resultant(f, g, K, includePRS=False):
@@ -483,10 +471,9 @@ def dmp_inner_subresultants(f, g, u, K):
     >>> b = -3*y**10 - 12*y**7 + y**6 - 54*y**4 + 8*y**3 + 729*y**2 - 216*y + 16
 
     >>> prs = [f, g, a, b]
-    >>> beta = [[-1], [1], [9, 0, 0, 0, 0, 0, 0, 0, 0]]
-    >>> delta = [0, 1, 1]
+    >>> sres = [[1], [1], [3, 0, 0, 0, 0], [-3, 0, 0, -12, 1, 0, -54, 8, 729, -216, 16]]
 
-    >>> R.dmp_inner_subresultants(f, g) == (prs, beta, delta)
+    >>> R.dmp_inner_subresultants(f, g) == (prs, sres)
     True
 
     """
@@ -500,48 +487,51 @@ def dmp_inner_subresultants(f, g, u, K):
         f, g = g, f
         n, m = m, n
 
+    if dmp_zero_p(f, u):
+        return [], []
+
+    v = u - 1
+    if dmp_zero_p(g, u):
+        return [f], [dmp_ground(K.one, v)]
+
     R = [f, g]
     d = n - m
-    v = u - 1
 
     b = dmp_pow(dmp_ground(-K.one, v), d + 1, v, K)
-    c = dmp_ground(-K.one, v)
-
-    B, D = [b], [d]
-
-    if dmp_zero_p(f, u) or dmp_zero_p(g, u):
-        return R, B, D
 
     h = dmp_prem(f, g, u, K)
     h = dmp_mul_term(h, b, 0, u, K)
 
+    lc = dmp_LC(g, K)
+    c = dmp_pow(lc, d, v, K)
+
+    S = [dmp_ground(K.one, v), c]
+    c = dmp_neg(c, v, K)
+
     while not dmp_zero_p(h, u):
         k = dmp_degree(h, u)
         R.append(h)
 
-        lc = dmp_LC(g, K)
-
-        p = dmp_pow(dmp_neg(lc, v, K), d, v, K)
-
-        if not d:
-            q = c
-        else:
-            q = dmp_pow(c, d - 1, v, K)
-
-        c = dmp_quo(p, q, v, K)
-        b = dmp_mul(dmp_neg(lc, v, K),
-                    dmp_pow(c, m - k, v, K), v, K)
-
         f, g, m, d = g, h, k, m - k
 
-        B.append(b)
-        D.append(d)
+        b = dmp_mul(dmp_neg(lc, v, K),
+                    dmp_pow(c, d, v, K), v, K)
 
         h = dmp_prem(f, g, u, K)
-
         h = [ dmp_quo(ch, b, v, K) for ch in h ]
 
-    return R, B, D
+        lc = dmp_LC(g, K)
+
+        if d > 1:
+            p = dmp_pow(dmp_neg(lc, v, K), d, v, K)
+            q = dmp_pow(c, d - 1, v, K)
+            c = dmp_quo(p, q, v, K)
+        else:
+            c = dmp_neg(lc, v, K)
+
+        S.append(dmp_neg(c, v, K))
+
+    return R, S
 
 
 def dmp_subresultants(f, g, u, K):
@@ -599,43 +589,12 @@ def dmp_prs_resultant(f, g, u, K):
     if dmp_zero_p(f, u) or dmp_zero_p(g, u):
         return (dmp_zero(u - 1), [])
 
-    R, B, D = dmp_inner_subresultants(f, g, u, K)
+    R, S = dmp_inner_subresultants(f, g, u, K)
 
     if dmp_degree(R[-1], u) > 0:
         return (dmp_zero(u - 1), R)
-    if dmp_one_p(R[-2], u, K):
-        return (dmp_LC(R[-1], K), R)
 
-    s, i, v = 1, 1, u - 1
-
-    p = dmp_one(v, K)
-    q = dmp_one(v, K)
-
-    for b, d in list(zip(B, D))[:-1]:
-        du = dmp_degree(R[i - 1], u)
-        dv = dmp_degree(R[i  ], u)
-        dw = dmp_degree(R[i + 1], u)
-
-        if du % 2 and dv % 2:
-            s = -s
-
-        lc, i = dmp_LC(R[i], K), i + 1
-
-        p = dmp_mul(dmp_mul(p, dmp_pow(b, dv, v, K), v, K),
-                    dmp_pow(lc, du - dw, v, K), v, K)
-        q = dmp_mul(q, dmp_pow(lc, dv*(1 + d), v, K), v, K)
-
-        _, p, q = dmp_inner_gcd(p, q, v, K)
-
-    if s < 0:
-        p = dmp_neg(p, v, K)
-
-    i = dmp_degree(R[-2], u)
-
-    res = dmp_pow(dmp_LC(R[-1], K), i, v, K)
-    res = dmp_quo(dmp_mul(res, p, v, K), q, v, K)
-
-    return res, R
+    return S[-1], R
 
 
 def dmp_zz_modular_resultant(f, g, p, u, K):
@@ -939,6 +898,7 @@ def _dmp_rr_trivial_gcd(f, g, u, K):
     """Handle trivial cases in GCD algorithm over a ring. """
     zero_f = dmp_zero_p(f, u)
     zero_g = dmp_zero_p(g, u)
+    if_contain_one = dmp_one_p(f, u, K) or dmp_one_p(g, u, K)
 
     if zero_f and zero_g:
         return tuple(dmp_zeros(3, u, K))
@@ -952,6 +912,8 @@ def _dmp_rr_trivial_gcd(f, g, u, K):
             return f, dmp_one(u, K), dmp_zero(u)
         else:
             return dmp_neg(f, u, K), dmp_ground(-K.one, u), dmp_zero(u)
+    elif if_contain_one:
+        return dmp_one(u, K), f, g
     elif query('USE_SIMPLIFY_GCD'):
         return _dmp_simplify_gcd(f, g, u, K)
     else:
@@ -1244,7 +1206,7 @@ def dup_zz_heu_gcd(f, g, K):
             2*min(f_norm // abs(dup_LC(f, K)),
                   g_norm // abs(dup_LC(g, K))) + 2)
 
-    for i in xrange(0, HEU_GCD_MAX):
+    for i in range(0, HEU_GCD_MAX):
         ff = dup_eval(f, x, K)
         gg = dup_eval(g, x, K)
 
@@ -1369,7 +1331,7 @@ def dmp_zz_heu_gcd(f, g, u, K):
             2*min(f_norm // abs(dmp_ground_LC(f, u, K)),
                   g_norm // abs(dmp_ground_LC(g, u, K))) + 2)
 
-    for i in xrange(0, HEU_GCD_MAX):
+    for i in range(0, HEU_GCD_MAX):
         ff = dmp_eval(f, x, u, K)
         gg = dmp_eval(g, x, u, K)
 
