@@ -4,30 +4,33 @@ from itertools import product
 
 from sympy.core.sympify import _sympify, sympify
 from sympy.core.basic import Basic
+from sympy.core.expr import Expr
 from sympy.core.singleton import Singleton, S
 from sympy.core.evalf import EvalfMixin
 from sympy.core.numbers import Float
-from sympy.core.compatibility import iterable, with_metaclass, ordered
+from sympy.core.compatibility import iterable, with_metaclass, ordered, range
 from sympy.core.evaluate import global_evaluate
-from sympy.core.decorators import deprecated
 from sympy.core.mul import Mul
+from sympy.core.relational import Eq
+from sympy.core.symbol import Symbol
 from sympy.sets.contains import Contains
+from sympy.utilities.misc import func_name
 
-from sympy.mpmath import mpi, mpf
+from mpmath import mpi, mpf
 from sympy.logic.boolalg import And, Or, Not, true, false
-from sympy.utilities import default_sort_key, subsets
+from sympy.utilities import subsets
 
 
 class Set(Basic):
     """
     The base class for any kind of set.
 
-    This is not meant to be used directly as a container of items.
-    It does not behave like the builtin ``set``; see :class:`FiniteSet` for that.
+    This is not meant to be used directly as a container of items. It does not
+    behave like the builtin ``set``; see :class:`FiniteSet` for that.
 
-    Real intervals are represented by the :class:`Interval` class and unions of sets
-    by the :class:`Union` class. The empty set is represented by the :class:`EmptySet` class
-    and available as a singleton as ``S.EmptySet``.
+    Real intervals are represented by the :class:`Interval` class and unions of
+    sets by the :class:`Union` class. The empty set is represented by the
+    :class:`EmptySet` class and available as a singleton as ``S.EmptySet``.
     """
     is_number = False
     is_iterable = False
@@ -41,6 +44,7 @@ class Set(Basic):
     is_EmptySet = None
     is_UniversalSet = None
     is_Complement = None
+    is_ComplexRegion = False
 
     @staticmethod
     def _infimum_key(expr):
@@ -91,6 +95,12 @@ class Set(Basic):
         >>> Interval(1, 3).intersect(Interval(1, 2))
         [1, 2]
 
+        >>> from sympy import imageset, Lambda, symbols, S
+        >>> n, m = symbols('n m')
+        >>> a = imageset(Lambda(n, 2*n), S.Integers)
+        >>> a.intersect(imageset(Lambda(m, 2*m + 1), S.Integers))
+        EmptySet()
+
         """
         return Intersection(self, other)
 
@@ -177,7 +187,8 @@ class Set(Basic):
             # For each set consider it or it's complement
             # We need at least one of the sets to be complemented
             # Consider all 2^n combinations.
-            # We can conveniently represent these options easily using a ProductSet
+            # We can conveniently represent these options easily using a
+            # ProductSet
 
             # XXX: this doesn't work if the dimentions of the sets isn't same.
             # A - B is essentially same as A if B has a different
@@ -196,15 +207,19 @@ class Set(Basic):
             return Union(o - self for o in other.args)
 
         elif isinstance(other, Complement):
-            return Complement(other.args[0], Union(other.args[1], self))
+            return Complement(other.args[0], Union(other.args[1], self), evaluate=False)
 
         elif isinstance(other, EmptySet):
             return S.EmptySet
 
         elif isinstance(other, FiniteSet):
-            return FiniteSet(*[el for el in other if el not in self])
+            return FiniteSet(*[el for el in other if self.contains(el) != True])
 
-        return None
+    def symmetric_difference(self, other):
+        return SymmetricDifference(self, other)
+
+    def _symmetric_difference(self, other):
+        return Union(Complement(self, other), Complement(other, self))
 
     @property
     def inf(self):
@@ -264,7 +279,8 @@ class Set(Basic):
         True
 
         """
-        ret = self._contains(sympify(other, strict=True))
+        other = sympify(other, strict=True)
+        ret = sympify(self._contains(other))
         if ret is None:
             ret = Contains(other, self, evaluate=False)
         return ret
@@ -272,13 +288,6 @@ class Set(Basic):
     def _contains(self, other):
         raise NotImplementedError("(%s)._contains(%s)" % (self, other))
 
-    @deprecated(useinstead="is_subset", issue=7460, deprecated_since_version="0.7.6")
-    def subset(self, other):
-        """
-        Returns True if 'other' is a subset of 'self'.
-        """
-        return other.is_subset(self)
-
     def is_subset(self, other):
         """
         Returns True if 'self' is a subset of 'other'.
@@ -382,7 +391,8 @@ class Set(Basic):
         >>> A.powerset()
         {EmptySet()}
         >>> A = FiniteSet(1, 2)
-        >>> A.powerset() == FiniteSet(FiniteSet(1), FiniteSet(2), FiniteSet(1, 2), EmptySet())
+        >>> a, b, c = FiniteSet(1), FiniteSet(2), FiniteSet(1, 2)
+        >>> A.powerset() == FiniteSet(a, b, c, EmptySet())
         True
 
         References
@@ -483,6 +493,9 @@ class Set(Basic):
     def __mul__(self, other):
         return ProductSet(self, other)
 
+    def __xor__(self, other):
+        return SymmetricDifference(self, other)
+
     def __pow__(self, exp):
         if not sympify(exp).is_Integer and exp >= 0:
             raise ValueError("%s: Exponent must be a positive Integer" % exp)
@@ -492,16 +505,11 @@ class Set(Basic):
         return Complement(self, other)
 
     def __contains__(self, other):
-        symb = self.contains(other)
-        if symb not in (true, false):
+        symb = sympify(self.contains(other))
+        if not (symb is S.true or symb is S.false):
             raise TypeError('contains did not evaluate to a bool: %r' % symb)
         return bool(symb)
 
-    @property
-    @deprecated(useinstead="is_subset(Reals)", issue=6212, deprecated_since_version="0.7.6")
-    def is_real(self):
-        return None
-
 
 class ProductSet(Set):
     """
@@ -564,6 +572,15 @@ class ProductSet(Set):
 
         return Basic.__new__(cls, *sets, **assumptions)
 
+    def _eval_Eq(self, other):
+        if not other.is_ProductSet:
+            return
+
+        if len(self.args) != len(other.args):
+            return false
+
+        return And(*(Eq(x, y) for x, y in zip(self.args, other.args)))
+
     def _contains(self, element):
         """
         'in' operator for ProductSets
@@ -585,7 +602,8 @@ class ProductSet(Set):
                 return false
         except TypeError:  # maybe element isn't an iterable
             return false
-        return And(*[set.contains(item) for set, item in zip(self.sets, element)])
+        return And(*
+            [set.contains(item) for set, item in zip(self.sets, element)])
 
     def _intersect(self, other):
         """
@@ -624,11 +642,6 @@ class ProductSet(Set):
                                 for i, a in enumerate(self.sets))
 
 
-    @property
-    @deprecated(useinstead="is_subset(Reals)", issue=6212, deprecated_since_version="0.7.6")
-    def is_real(self):
-        return all(set.is_real for set in self.sets)
-
     @property
     def is_iterable(self):
         return all(set.is_iterable for set in self.sets)
@@ -669,6 +682,12 @@ class Interval(Set, EvalfMixin):
     [0, 1]
     >>> Interval(0, 1, False, True)
     [0, 1)
+    >>> Interval.Ropen(0, 1)
+    [0, 1)
+    >>> Interval.Lopen(0, 1)
+    (0, 1]
+    >>> Interval.open(0, 1)
+    (0, 1)
 
     >>> a = Symbol('a', real=True)
     >>> Interval(0, a)
@@ -688,11 +707,6 @@ class Interval(Set, EvalfMixin):
     """
     is_Interval = True
 
-    @property
-    @deprecated(useinstead="is_subset(Reals)", issue=6212, deprecated_since_version="0.7.6")
-    def is_real(self):
-        return True
-
     def __new__(cls, start, end, left_open=False, right_open=False):
 
         start = _sympify(start)
@@ -700,20 +714,22 @@ class Interval(Set, EvalfMixin):
         left_open = _sympify(left_open)
         right_open = _sympify(right_open)
 
-        if not all(isinstance(a, (type(true), type(false))) for a in [left_open, right_open]):
+        if not all(isinstance(a, (type(true), type(false)))
+            for a in [left_open, right_open]):
             raise NotImplementedError(
                 "left_open and right_open can have only true/false values, "
                 "got %s and %s" % (left_open, right_open))
 
         inftys = [S.Infinity, S.NegativeInfinity]
         # Only allow real intervals (use symbols with 'is_real=True').
-        if not (start.is_real or start in inftys) or not (end.is_real or end in inftys):
-            raise ValueError("Only real intervals are supported")
+        if not all(i.is_real is not False or i in inftys for i in (start, end)):
+            raise ValueError("Non-real intervals are not supported")
 
-        # Make sure that the created interval will be valid.
-        if end.is_comparable and start.is_comparable:
-            if end < start:
-                return S.EmptySet
+        # evaluate if possible
+        if (end < start) == True:
+            return S.EmptySet
+        elif (end - start).is_negative:
+            return S.EmptySet
 
         if end == start and (left_open or right_open):
             return S.EmptySet
@@ -747,6 +763,21 @@ class Interval(Set, EvalfMixin):
 
     _inf = left = start
 
+    @classmethod
+    def open(cls, a, b):
+        """Return an interval including neither boundary."""
+        return cls(a, b, True, True)
+
+    @classmethod
+    def Lopen(cls, a, b):
+        """Return an interval not including the left boundary."""
+        return cls(a, b, True, False)
+
+    @classmethod
+    def Ropen(cls, a, b):
+        """Return an interval not including the right boundary."""
+        return cls(a, b, False, True)
+
     @property
     def end(self):
         """
@@ -809,6 +840,14 @@ class Interval(Set, EvalfMixin):
         # We only know how to intersect with other intervals
         if not other.is_Interval:
             return None
+
+        # handle (-oo, oo)
+        infty = S.NegativeInfinity, S.Infinity
+        if self == Interval(*infty):
+            l, r = self.left, self.right
+            if l.is_real or l in infty or r.is_real or r in infty:
+                return other
+
         # We can't intersect [0,3] with [x,6] -- we don't know if x>0 or x<0
         if not self._is_comparable(other):
             return None
@@ -849,12 +888,17 @@ class Interval(Set, EvalfMixin):
 
 
     def _complement(self, other):
-        if other is S.Reals:
+        if other == S.Reals:
             a = Interval(S.NegativeInfinity, self.start,
                          True, not self.left_open)
             b = Interval(self.end, S.Infinity, not self.right_open, True)
             return Union(a, b)
 
+        if isinstance(other, FiniteSet):
+            nums = [m for m in other.args if m.is_number]
+            if nums == []:
+                return None
+
         return Set._complement(self, other)
 
 
@@ -884,8 +928,8 @@ class Interval(Set, EvalfMixin):
                 return Interval(start, end, left_open, right_open)
 
         # If I have open end points and these endpoints are contained in other
-        if ((self.left_open and other.contains(self.start) is true) or
-                (self.right_open and other.contains(self.end) is true)):
+        if ((self.left_open and sympify(other.contains(self.start)) is S.true) or
+                (self.right_open and sympify(other.contains(self.end)) is S.true)):
             # Fill in my end points and return
             open_left = self.left_open and self.start not in other
             open_right = self.right_open and self.end not in other
@@ -899,9 +943,17 @@ class Interval(Set, EvalfMixin):
         return FiniteSet(self.start, self.end)
 
     def _contains(self, other):
-        if other.is_real is False:
+        if not isinstance(other, Expr) or (
+                other is S.Infinity or
+                other is S.NegativeInfinity or
+                other is S.NaN or
+                other is S.ComplexInfinity) or other.is_real is False:
             return false
 
+        if self.start is S.NegativeInfinity and self.end is S.Infinity:
+            if not other.is_real is None:
+                return other.is_real
+
         if self.left_open:
             expr = other > self.start
         else:
@@ -916,11 +968,10 @@ class Interval(Set, EvalfMixin):
 
     def _eval_imageset(self, f):
         from sympy.functions.elementary.miscellaneous import Min, Max
-        from sympy.solvers import solve
-        from sympy.core.function import diff
+        from sympy.solvers.solveset import solveset
+        from sympy.core.function import diff, Lambda
         from sympy.series import limit
         from sympy.calculus.singularities import singularities
-        # TODO: handle piecewise defined functions
         # TODO: handle functions with infinitely many solutions (eg, sin, tan)
         # TODO: handle multivariate functions
 
@@ -929,11 +980,34 @@ class Interval(Set, EvalfMixin):
             return
         var = f.variables[0]
 
+        if expr.is_Piecewise:
+            result = S.EmptySet
+            domain_set = self
+            for (p_expr, p_cond) in expr.args:
+                if p_cond is true:
+                    intrvl = domain_set
+                else:
+                    intrvl = p_cond.as_set()
+                    intrvl = Intersection(domain_set, intrvl)
+
+                if p_expr.is_Number:
+                    image = FiniteSet(p_expr)
+                else:
+                    image = imageset(Lambda(var, p_expr), intrvl)
+                result = Union(result, image)
+
+                # remove the part which has been `imaged`
+                domain_set = Complement(domain_set, intrvl)
+                if domain_set.is_EmptySet:
+                    break
+            return result
+
         if not self.start.is_comparable or not self.end.is_comparable:
             return
 
         try:
-            sing = [x for x in singularities(expr, var) if x.is_real and x in self]
+            sing = [x for x in singularities(expr, var)
+                if x.is_real and x in self]
         except NotImplementedError:
             return
 
@@ -947,7 +1021,7 @@ class Interval(Set, EvalfMixin):
             _end = f(self.end)
 
         if len(sing) == 0:
-            solns = solve(diff(expr, var), var)
+            solns = list(solveset(diff(expr, var), var))
 
             extr = [_start, _end] + [f(x) for x in solns
                                      if x.is_real and x in self]
@@ -972,8 +1046,8 @@ class Interval(Set, EvalfMixin):
         else:
             return imageset(f, Interval(self.start, sing[0],
                                         self.left_open, True)) + \
-                Union(*[imageset(f, Interval(sing[i], sing[i + 1]), True, True)
-                        for i in range(1, len(sing) - 1)]) + \
+                Union(*[imageset(f, Interval(sing[i], sing[i + 1], True, True))
+                        for i in range(0, len(sing) - 1)]) + \
                 imageset(f, Interval(sing[-1], self.end, True, self.right_open))
 
     @property
@@ -981,10 +1055,12 @@ class Interval(Set, EvalfMixin):
         return self.end - self.start
 
     def to_mpi(self, prec=53):
-        return mpi(mpf(self.start.evalf(prec)), mpf(self.end.evalf(prec)))
+        return mpi(mpf(self.start._eval_evalf(prec)),
+            mpf(self.end._eval_evalf(prec)))
 
     def _eval_evalf(self, prec):
-        return Interval(self.left.evalf(), self.right.evalf(),
+        return Interval(self.left._eval_evalf(prec),
+            self.right._eval_evalf(prec),
                         left_open=self.left_open, right_open=self.right_open)
 
     def _is_comparable(self, other):
@@ -1005,24 +1081,32 @@ class Interval(Set, EvalfMixin):
         """Return ``True`` if the right endpoint is positive infinity. """
         return self.right is S.Infinity or self.right == Float("+inf")
 
-    def as_relational(self, symbol):
-        """Rewrite an interval in terms of inequalities and logic operators. """
-        other = sympify(symbol)
+    def as_relational(self, x):
+        """Rewrite an interval in terms of inequalities and logic operators."""
+        x = sympify(x)
         if self.right_open:
-            right = other < self.end
+            right = x < self.end
         else:
-            right = other <= self.end
-        if right == True:
-            if self.left_open:
-                return other > self.start
-            else:
-                return other >= self.start
+            right = x <= self.end
         if self.left_open:
-            left = self.start < other
+            left = self.start < x
         else:
-            left = self.start <= other
+            left = self.start <= x
         return And(left, right)
 
+    def _eval_Eq(self, other):
+        if not other.is_Interval:
+            if (other.is_Union or other.is_Complement or
+                other.is_Intersection or other.is_ProductSet):
+                return
+
+            return false
+
+        return And(Eq(self.left, other.left),
+                   Eq(self.right, other.right),
+                   self.left_open == other.left_open,
+                   self.right_open == other.right_open)
+
 
 class Union(Set, EvalfMixin):
     """
@@ -1127,7 +1211,7 @@ class Union(Set, EvalfMixin):
         else:
             return Union(args, evaluate=False)
 
-    def complement(self, universe):
+    def _complement(self, universe):
         # DeMorgan's Law
         return Intersection(s.complement(universe) for s in self.args)
 
@@ -1146,8 +1230,7 @@ class Union(Set, EvalfMixin):
         return Max(*[set.sup for set in self.args])
 
     def _contains(self, other):
-        or_args = [the_set.contains(other) for the_set in self.args]
-        return Or(*or_args)
+        return Or(*[set.contains(other) for set in self.args])
 
     @property
     def _measure(self):
@@ -1217,23 +1300,33 @@ class Union(Set, EvalfMixin):
 
     def _eval_evalf(self, prec):
         try:
-            return Union(set.evalf() for set in self.args)
+            return Union(set._eval_evalf(prec) for set in self.args)
         except Exception:
             raise TypeError("Not all sets are evalf-able")
 
     def __iter__(self):
         import itertools
+
+        # roundrobin recipe taken from itertools documentation:
+        # https://docs.python.org/2/library/itertools.html#recipes
+        def roundrobin(*iterables):
+            "roundrobin('ABC', 'D', 'EF') --> A D E B F C"
+            # Recipe credited to George Sakkis
+            pending = len(iterables)
+            nexts = itertools.cycle(iter(it).next for it in iterables)
+            while pending:
+                try:
+                    for next in nexts:
+                        yield next()
+                except StopIteration:
+                    pending -= 1
+                    nexts = itertools.cycle(itertools.islice(nexts, pending))
+
         if all(set.is_iterable for set in self.args):
-            return itertools.chain(*(iter(arg) for arg in self.args))
+            return roundrobin(*(iter(arg) for arg in self.args))
         else:
             raise TypeError("Not all constituent sets are iterable")
 
-    @property
-    @deprecated(useinstead="is_subset(Reals)", issue=6212, deprecated_since_version="0.7.6")
-    def is_real(self):
-        return all(set.is_real for set in self.args)
-
-
 class Intersection(Set):
     """
     Represents an intersection of sets as a :class:`Set`.
@@ -1280,14 +1373,16 @@ class Intersection(Set):
         args = flatten(args)
 
         if len(args) == 0:
-            raise TypeError("Intersection expected at least one argument")
+            return S.EmptySet
+
+        # args can't be ordered for Partition see issue #9608
+        if 'Partition' not in [type(a).__name__ for a in args]:
+            args = list(ordered(args, Set._infimum_key))
 
         # Reduce sets using known rules
         if evaluate:
             return Intersection.reduce(args)
 
-        args = list(ordered(args, Set._infimum_key))
-
         return Basic.__new__(cls, *args)
 
     @property
@@ -1306,17 +1401,92 @@ class Intersection(Set):
         return Intersection(imageset(f, arg) for arg in self.args)
 
     def _contains(self, other):
-        from sympy.logic.boolalg import And
         return And(*[set.contains(other) for set in self.args])
 
     def __iter__(self):
+        no_iter = True
         for s in self.args:
             if s.is_iterable:
+                no_iter = False
                 other_sets = set(self.args) - set((s,))
                 other = Intersection(other_sets, evaluate=False)
-                return (x for x in s if x in other)
+                for x in s:
+                    c = sympify(other.contains(x))
+                    if c is S.true:
+                        yield x
+                    elif c is S.false:
+                        pass
+                    else:
+                        yield c
 
-        raise ValueError("None of the constituent sets are iterable")
+        if no_iter:
+            raise ValueError("None of the constituent sets are iterable")
+
+    @staticmethod
+    def _handle_finite_sets(args):
+        from sympy.core.logic import fuzzy_and, fuzzy_bool
+        from sympy.core.compatibility import zip_longest
+
+        new_args = []
+        fs_args = []
+        for s in args:
+            if s.is_FiniteSet:
+                fs_args.append(s)
+            else:
+                new_args.append(s)
+        if not fs_args:
+            return
+        s = fs_args[0]
+        fs_args = fs_args[1:]
+        res = []
+        unk = []
+        for x in s:
+            c = fuzzy_and(fuzzy_bool(o.contains(x))
+                for o in fs_args + new_args)
+            if c:
+                res.append(x)
+            elif c is None:
+                unk.append(x)
+            else:
+                pass  # drop arg
+        res = FiniteSet(
+            *res, evaluate=False) if res else S.EmptySet
+        if unk:
+            symbolic_s_list = [x for x in s if x.has(Symbol)]
+            non_symbolic_s = s - FiniteSet(
+                *symbolic_s_list, evaluate=False)
+            while fs_args:
+                v = fs_args.pop()
+                if all(i == j for i, j in zip_longest(
+                        symbolic_s_list,
+                        (x for x in v if x.has(Symbol)))):
+                    # all the symbolic elements of `v` are the same
+                    # as in `s` so remove the non-symbol containing
+                    # expressions from `unk`, since they cannot be
+                    # contained
+                    for x in non_symbolic_s:
+                        if x in unk:
+                            unk.remove(x)
+                else:
+                    # if only a subset of elements in `s` are
+                    # contained in `v` then remove them from `v`
+                    # and add this as a new arg
+                    contained = [x for x in symbolic_s_list
+                        if sympify(v.contains(x)) is S.true]
+                    if contained != symbolic_s_list:
+                        new_args.append(
+                            v - FiniteSet(
+                            *contained, evaluate=False))
+                    else:
+                        pass  # for coverage
+
+            other_sets = Intersection(*new_args)
+            if not other_sets:
+                return S.EmptySet  # b/c we use evaluate=False below
+            res += Intersection(
+                FiniteSet(*unk),
+                other_sets, evaluate=False)
+        return res
 
     @staticmethod
     def reduce(args):
@@ -1335,12 +1505,10 @@ class Intersection(Set):
         if any(s.is_EmptySet for s in args):
             return S.EmptySet
 
-        # If any FiniteSets see which elements of that finite set occur within
-        # all other sets in the intersection
-        for s in args:
-            if s.is_FiniteSet:
-                return s.func(*[x for x in s
-                                if all(other.contains(x) == True for other in args)])
+        # Handle Finite sets
+        rv = Intersection._handle_finite_sets(args)
+        if rv is not None:
+            return rv
 
         # If any of the sets are unions, return a Union of Intersections
         for s in args:
@@ -1390,8 +1558,8 @@ class Intersection(Set):
 
 
 class Complement(Set, EvalfMixin):
-    """
-    Represents the set difference or relative complement of a set with another set.
+    """Represents the set difference or relative complement of a set with
+    another set.
 
     `A - B = \{x \in A| x \\notin B\}`
 
@@ -1405,11 +1573,13 @@ class Complement(Set, EvalfMixin):
 
     See Also
     =========
+
     Intersection, Union
 
     References
     ==========
-    http://mathworld.wolfram.com/SetComplement.html
+
+    .. [1] http://mathworld.wolfram.com/ComplementSet.html
     """
 
     is_Complement = True
@@ -1504,6 +1674,12 @@ class EmptySet(with_metaclass(Singleton, Set)):
     def _boundary(self):
         return self
 
+    def _complement(self, other):
+        return other
+
+    def _symmetric_difference(self, other):
+        return other
+
 
 class UniversalSet(with_metaclass(Singleton, Set)):
     """
@@ -1536,9 +1712,12 @@ class UniversalSet(with_metaclass(Singleton, Set)):
     def _intersect(self, other):
         return other
 
-    def complement(self, universal_set):
+    def _complement(self, other):
         return S.EmptySet
 
+    def _symmetric_difference(self, other):
+        return other
+
     @property
     def _measure(self):
         return S.Infinity
@@ -1570,6 +1749,10 @@ class FiniteSet(Set, EvalfMixin):
     >>> 3 in FiniteSet(1, 2, 3, 4)
     True
 
+    >>> members = [1, 2, 3, 4]
+    >>> FiniteSet(*members)
+    {1, 2, 3, 4}
+
     References
     ==========
 
@@ -1593,6 +1776,19 @@ class FiniteSet(Set, EvalfMixin):
         obj._elements = frozenset(args)
         return obj
 
+    def _eval_Eq(self, other):
+        if not other.is_FiniteSet:
+            if (other.is_Union or other.is_Complement or
+                other.is_Intersection or other.is_ProductSet):
+                return
+
+            return false
+
+        if len(self) != len(other):
+            return false
+
+        return And(*(Eq(x, y) for x, y in zip(self.args, other.args)))
+
     def __iter__(self):
         return iter(self.args)
 
@@ -1604,25 +1800,44 @@ class FiniteSet(Set, EvalfMixin):
         """
         if isinstance(other, self.__class__):
             return self.__class__(*(self._elements & other._elements))
-        return self.__class__(el for el in self if el in other)
+        return self.__class__(*[el for el in self if el in other])
 
     def _complement(self, other):
-        if other is S.Reals:
+        if isinstance(other, Interval):
             nums = sorted(m for m in self.args if m.is_number)
-            syms = [m for m in self.args if m.is_Symbol]
-            # Reals cannot contain elements other than numbers and symbols.
+            if other == S.Reals and nums != []:
+                syms = [m for m in self.args if m.is_Symbol]
+                # Reals cannot contain elements other than numbers and symbols.
 
-            intervals = []  # Build up a list of intervals between the elements
-            if nums != []:
+                intervals = []  # Build up a list of intervals between the elements
                 intervals += [Interval(S.NegativeInfinity, nums[0], True, True)]
                 for a, b in zip(nums[:-1], nums[1:]):
-                    intervals.append(Interval(a, b, True, True))  # open intervals
+                    intervals.append(Interval(a, b, True, True))  # both open
                 intervals.append(Interval(nums[-1], S.Infinity, True, True))
 
-            if syms != []:
-                return Complement(Union(intervals, evaluate=False), FiniteSet(*syms), evaluate=False)
-            else:
-                return Union(intervals, evaluate=False)
+                if syms != []:
+                    return Complement(Union(intervals, evaluate=False),
+                            FiniteSet(*syms), evaluate=False)
+                else:
+                    return Union(intervals, evaluate=False)
+            elif nums == []:
+                return None
+
+        elif isinstance(other, FiniteSet):
+            unk = []
+            for i in self:
+                c = sympify(other.contains(i))
+                if c is not S.true and c is not S.false:
+                    unk.append(i)
+            unk = FiniteSet(*unk)
+            if unk == self:
+                return
+            not_true = []
+            for i in other:
+                c = sympify(self.contains(i))
+                if c is not S.true:
+                    not_true.append(i)
+            return Complement(FiniteSet(*not_true), unk)
 
         return Set._complement(self, other)
 
@@ -1637,13 +1852,14 @@ class FiniteSet(Set, EvalfMixin):
             return FiniteSet(*(self._elements | other._elements))
 
         # If other set contains one of my elements, remove it from myself
-        if any(other.contains(x) is true for x in self):
+        if any(sympify(other.contains(x)) is S.true for x in self):
             return set((
-                FiniteSet(*[x for x in self if other.contains(x) is not true]),
-                other))
+                FiniteSet(*[x for x in self
+                    if other.contains(x) != True]), other))
 
         return None
 
+
     def _contains(self, other):
         """
         Tests whether an element, other, is in the set.
@@ -1661,13 +1877,16 @@ class FiniteSet(Set, EvalfMixin):
         False
 
         """
-        if other in self._elements:
-            return true
-        else:
-            if not other.free_symbols:
-                return false
-            elif all(e.is_Symbol for e in self._elements):
-                return false
+        r = false
+        for e in self._elements:
+            t = Eq(e, other, evaluate=True)
+            if isinstance(t, Eq):
+                t = t.simplify()
+            if t == true:
+                return t
+            elif t != false:
+                r = None
+        return r
 
     def _eval_imageset(self, f):
         return FiniteSet(*map(f, self))
@@ -1698,41 +1917,82 @@ class FiniteSet(Set, EvalfMixin):
         from sympy.core.relational import Eq
         return Or(*[Eq(symbol, elem) for elem in self])
 
-    @property
-    @deprecated(useinstead="is_subset(Reals)", issue=6212, deprecated_since_version="0.7.6")
-    def is_real(self):
-        return all(el.is_real for el in self)
-
     def compare(self, other):
         return (hash(self) - hash(other))
 
     def _eval_evalf(self, prec):
-        return FiniteSet(*[elem.evalf(prec) for elem in self])
+        return FiniteSet(*[elem._eval_evalf(prec) for elem in self])
 
     def _hashable_content(self):
         return (self._elements,)
 
     @property
     def _sorted_args(self):
-        from sympy.utilities import default_sort_key
         return tuple(ordered(self.args, Set._infimum_key))
 
     def _eval_powerset(self):
         return self.func(*[self.func(*s) for s in subsets(self.args)])
 
     def __ge__(self, other):
+        if not isinstance(other, Set):
+            raise TypeError("Invalid comparison of set with %s" % func_name(other))
         return other.is_subset(self)
 
     def __gt__(self, other):
+        if not isinstance(other, Set):
+            raise TypeError("Invalid comparison of set with %s" % func_name(other))
         return self.is_proper_superset(other)
 
     def __le__(self, other):
+        if not isinstance(other, Set):
+            raise TypeError("Invalid comparison of set with %s" % func_name(other))
         return self.is_subset(other)
 
     def __lt__(self, other):
+        if not isinstance(other, Set):
+            raise TypeError("Invalid comparison of set with %s" % func_name(other))
         return self.is_proper_subset(other)
 
 
+class SymmetricDifference(Set):
+    """Represents the set of elements which are in either of the
+    sets and not in their intersection.
+
+    Examples
+    ========
+
+    >>> from sympy import SymmetricDifference, FiniteSet
+    >>> SymmetricDifference(FiniteSet(1, 2, 3), FiniteSet(3, 4, 5))
+    {1, 2, 4, 5}
+
+    See Also
+    ========
+
+    Complement, Union
+
+    References
+    ==========
+
+    .. [1] http://en.wikipedia.org/wiki/Symmetric_difference
+    """
+
+    is_SymmetricDifference = True
+
+    def __new__(cls, a, b, evaluate=True):
+        if evaluate:
+            return SymmetricDifference.reduce(a, b)
+
+        return Basic.__new__(cls, a, b)
+
+    @staticmethod
+    def reduce(A, B):
+        result = B._symmetric_difference(A)
+        if result is not None:
+            return result
+        else:
+            return SymmetricDifference(A, B, evaluate=False)
+
+
 def imageset(*args):
     r"""
     Image of set under transformation ``f``.
